==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translation>Nessun limite selezionato.</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translation>Contorno non è chiuso al punto %1/%2.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation>Ogni entità confine deve essere una linea, arco, cerchio, arco ellittico, ellissi, polilinee o spline. Trovato:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Tratteggi</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translation>Disegna un tratteggio o un riempimento uniforme</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Tratteggi</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Riempimento</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Modello tratteggio</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Modello</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Angolo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Scala:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translation type="vanished">Nessun limite selezionato.</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translation type="vanished">Contorno non è chiuso al punto %1/%2.</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation type="vanished">Ogni entità confine deve essere una linea, arco, cerchio, arco ellittico, ellissi, polilinee o spline. Trovato:</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation>Menù tratteggi</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation>Mostra menù tratteggi</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Tratteggi</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translation type="vanished">Disegna un tratteggio o un riempimento uniforme</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Tratteggi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Riempimento</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Modello tratteggio</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Modello</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Angolo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Scala:</translation>
    </message>
</context>
</TS>
